@@ -134,6 +134,8 @@ Backend::~Backend()
 
 QObject *Backend::createObject(BackendInterface::Class c, QObject *parent, const QList<QVariant> &args)
 {
+    if (!LibVLC::self || !libvlc)
+        return 0;
 #ifndef PHONON_VLC_NO_EXPERIMENTAL
     Phonon::Experimental::BackendInterface::Class cex = static_cast<Phonon::Experimental::BackendInterface::Class>(c);
 
@@ -220,6 +222,7 @@ QStringList Backend::availableMimeTypes() const
                 << QLatin1String("audio/x-8svx")
                 << QLatin1String("audio/x-aiff")
                 << QLatin1String("audio/x-basic")
+                << QLatin1String("audio/x-it")
                 << QLatin1String("audio/x-m4a")
                 << QLatin1String("audio/x-mp3")
                 << QLatin1String("audio/x-mpeg")
@@ -235,9 +238,11 @@ QStringList Backend::availableMimeTypes() const
                 << QLatin1String("audio/x-pn-windows-acm")
                 << QLatin1String("audio/x-real-audio")
                 << QLatin1String("audio/x-realaudio")
+                << QLatin1String("audio/x-s3m")
                 << QLatin1String("audio/x-speex+ogg")
                 << QLatin1String("audio/x-vorbis+ogg")
                 << QLatin1String("audio/x-wav")
+                << QLatin1String("audio/x-xm")
                 << QLatin1String("image/ilbm")
                 << QLatin1String("image/png")
                 << QLatin1String("image/x-ilbm")
